@@ -15,10 +15,12 @@
 #' @importFrom bitops bitAnd
 #' @import rpart
 #' @importFrom methods hasArg
+#' @importFrom data.table data.table
 NULL
 
-
-
+.SCALE_METRIC = 2
+.SCALE_ORDINAL = 3
+.SCALE_CATEGORICAL = 1
 
 
 
